DatedRewards class

Constructors

DatedRewards(List<String> dates, Map<String, List<RewardsModel>> rewards)

Properties

dates → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
rewards → Map<String, List<RewardsModel>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map temp) → (List<String>, Map<String, List<RewardsModel>>)